@@ -40,12 +40,33 @@ else:
     from functools import cache
 
 
+LOGGING_CONFIG: dict = {
+    "version": 1,
+    "disable_existing_loggers": False,
+    "formatters": {
+        "default": {
+            'format': '[%(levelname)s] %(name)s: %(message)s'
+        },
+    },
+    "handlers": {
+        "default": {
+            "formatter": "default",
+            "class": "logging.StreamHandler",
+            "stream": "ext://sys.stderr",
+        },
+    },
+    "loggers": {
+        "patchwork": {"handlers": ["default"], "level": "INFO"},
+    },
+}
+
+
 class WorkerSettings(BaseModel):
 
     debug: bool = False
     enabled: bool = True
 
-    logging: LoggingConfig = None
+    logging: LoggingConfig = LOGGING_CONFIG
 
     # executor unit
     executor: ComponentConfig[Type[BaseExecutor]] = ComponentConfig(BaseExecutor)
@@ -79,7 +100,7 @@ class PatchworkWorker(Module):
 
     @cached_property
     def logger(self) -> logging.Logger:
-        return logging.getLogger('patchwork.worker')
+        return logging.getLogger('patchwork.node')
 
     @property
     def event_loop(self):
@@ -228,12 +249,12 @@ class PatchworkWorker(Module):
         self._setup_signals()
 
         self._setup_logger()
-        self.logger.debug("Worker initialized")
+        self.logger.info("Worker initialized")
 
         # first starts manager
         self.logger.debug("Starting manager")
         await self.manager.run()
-        self.logger.info("Manager started")
+        self.logger.debug("Manager started")
 
         # then start additional modules, all at once, if modules depends on each other should await
         # internally. Use get_module() worker method to get module instance and await on state flag
@@ -243,24 +264,26 @@ class PatchworkWorker(Module):
         if start_jobs:
             self.logger.debug("Starting additional modules")
             await asyncio.wait(start_jobs)
-            self.logger.info("All additional modules started")
+            self.logger.debug("All additional modules started")
         else:
             self.logger.debug("No additional modules to start")
 
         # start clients
         if self.settings.publisher is not None:
             await self.get_publisher().run()
-            self.logger.info("Publisher started")
+            self.logger.debug("Publisher started")
         else:
             self.logger.debug("No publisher configured")
 
         await self.get_subscriber().run()
-        self.logger.info("Subscriber started")
+        self.logger.debug("Subscriber started")
 
         # end executor at the end when everything is ready
         self.logger.debug("Starting executor")
         await self.executor.run()
-        self.logger.info("Executor started")
+        self.logger.debug("Executor started")
+
+        self.logger.info("Worker node is up and running")
 
         self.monitor_task = asyncio.create_task(self._monitor_submodules(
             (self.manager, self.executor) + tuple(self.modules.values())
@@ -325,15 +348,16 @@ class PatchworkWorker(Module):
             logging.config.dictConfig(self.settings.logging)
 
         now = time()
-        self.logger.info(f"Logging configured. Current time is {now} ({datetime.fromtimestamp(now)})")
+        self.logger.debug(f"Logging configured. Current time is {now} ({datetime.fromtimestamp(now)})")
 
-    def include_router(self, router: TaskRouter):
+    def include_router(self, router: TaskRouter, prefix: str = ''):
         """
         Register and setup given processor. Awaits until processor setup is done
-        :param router:
+        :param prefix: task type prefix for matching tasks
+        :param router: router to handle matching tasks
         :return:
         """
-        self.executor.add_router(router)
+        self.executor.add_router(router, prefix=prefix)
 
     def _setup_signals(self):
         # setup signals using asyncio
@@ -447,7 +471,7 @@ class PatchworkWorker(Module):
         # wait for executor, because working processors may depends on submodules, so terminate them
         # firstly
         await self.executor.terminate()
-        self.logger.info("Executor completed")
+        self.logger.debug("Executor completed")
 
         # stop clients, there should be no messages pending on clients as executor is completed
         await self.get_subscriber().terminate()
@@ -460,13 +484,13 @@ class PatchworkWorker(Module):
             self.logger.debug("Waiting for submodules stop jobs to complete...")
             # executor is down, stop all submodules simultaneously, stop jobs should not depends on each other
             await asyncio.wait(stop_jobs)
-            self.logger.info("Submodules completed")
+            self.logger.debug("Submodules completed")
         else:
             self.logger.debug("No stop jobs for submodules")
 
         self.logger.debug("Waiting for manager to stop...")
         await asyncio.wait([asyncio.create_task(self.manager.terminate())])
-        self.logger.info("Manager stopped")
+        self.logger.debug("Manager stopped")
 
         self_task = asyncio.current_task(loop=self._event_loop)
         tasks_left = [t for t in asyncio.all_tasks(self._event_loop) if not t.done() and t != self_task]
@@ -476,6 +500,8 @@ class PatchworkWorker(Module):
         else:
             self.logger.debug("No tasks left after stop job, event loop can be stopped clearly")
 
+        self.logger.info("Worker node completed")
+
     def _stop_job_done(self, fut: Future):
         fut.result()
         self._event_loop.stop()
